# -----------------------------------------------------------------------------
# © 2024 Boston Consulting Group. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# -----------------------------------------------------------------------------

"""
This section of the documentation provides detailed information
about the ARTKIT API, including descriptions of all classes, functions,
and modules with their respective arguments and return values.

For a general introduction to ARTKIT and its features, please refer to the
`Home page <../_generated/home.rst>`_ and our `User Guide <../user_guide/index.rst>`_.

This documentation is automatically generated using Sphinx, ensuring it
remains synchronized with the latest codebase updates.
"""

__version__ = "1.0.8"
